@@ -10,14 +10,13 @@
 *
 * $Project: /Convert-Binary-C $
 * $Author: mhx $
-* $Date: 2004/03/22 20:37:55 +0100 $
-* $Revision: 6 $
-* $Snapshot: /Convert-Binary-C/0.57 $
+* $Date: 2005/01/23 12:49:41 +0100 $
+* $Revision: 9 $
 * $Source: /ctlib/byteorder.h $
 *
 ********************************************************************************
 *
-* Copyright (c) 2002-2004 Marcus Holland-Moritz. All rights reserved.
+* Copyright (c) 2002-2005 Marcus Holland-Moritz. All rights reserved.
 * This program is free software; you can redistribute it and/or modify
 * it under the same terms as Perl itself.
 *
@@ -41,8 +40,8 @@
 
 typedef struct {
   enum {
-    BO_BIG_ENDIAN,
-    BO_LITTLE_ENDIAN
+    AS_BO_BIG_ENDIAN,
+    AS_BO_LITTLE_ENDIAN
   } bo;
 } ArchSpecs;
 
