@@ -10,13 +10,13 @@
 #
 # $Project: /Convert-Binary-C $
 # $Author: mhx $
-# $Date: 2006/01/01 10:38:23 +0100 $
-# $Revision: 21 $
+# $Date: 2005/02/21 10:18:41 +0100 $
+# $Revision: 18 $
 # $Source: /token/config.pl $
 #
 ################################################################################
 #
-# Copyright (c) 2002-2006 Marcus Holland-Moritz. All rights reserved.
+# Copyright (c) 2002-2005 Marcus Holland-Moritz. All rights reserved.
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
 #
@@ -25,7 +25,6 @@
 use Devel::Tokenizer::C;
 
 @options = qw(
-  UnsignedBitfields
   UnsignedChars
   Warnings
   PointerSize
@@ -50,7 +49,6 @@ use Devel::Tokenizer::C;
   HasCPPComments
   HasMacroVAARGS
   OrderMembers
-  Bitfields
 );
 
 @sourcify = qw(
